@@ -84,7 +84,7 @@ map_source_changed (GtkWidget *widget,
   gtk_tree_model_get (model, &iter, COL_ID, &id, -1);
 
   ChamplainMapSourceFactory *factory = champlain_map_source_factory_dup_default ();
-  source = champlain_map_source_factory_create (factory, id);
+  source = champlain_map_source_factory_create_cached_source (factory, id);
 
   g_object_set (G_OBJECT (view), "map-source", source, NULL);
   g_object_unref (factory);
@@ -226,6 +226,8 @@ main (int argc,
       "license-text", "Don't eat cereals with orange juice\nIt tastes bad",
       "show-scale", TRUE,
       NULL);
+  champlain_view_center_on(CHAMPLAIN_VIEW(view), 45.466, -73.75);
+
   layer = create_marker_layer (view);
   champlain_view_add_layer(view, layer);
   champlain_layer_hide_all_markers (CHAMPLAIN_LAYER (layer));
@@ -293,7 +295,6 @@ main (int argc,
 
   /* make sure that everything, window and label, are visible */
   gtk_widget_show_all (window);
-  champlain_view_center_on(CHAMPLAIN_VIEW(view), 45.466, -73.75);
   /* start the main loop */
   gtk_main ();
 
